@@ -5,10 +5,10 @@ molnet_config = {
                   '85266bf2676a86403863a32c8961fd8c',
                   'smiles',
                   ['u0_atom'], 'regression', '.', ['qm7.csv'], 'stratified', 'MAE'),
-    'QM7b': Config('https://s3-us-west-1.amazonaws.com/deepchem.io/datasets/molnet_publish/qm7b.zip',
-                   '4094d209daae761f579831f36d52e3ec',
-                   'smiles',
-                   [], 'regression', 'qm7b', ['qm7b.mat'], 'random', 'MAE'),
+    # 'QM7b': Config('https://s3-us-west-1.amazonaws.com/deepchem.io/datasets/molnet_publish/qm7b.zip',
+    #                '4094d209daae761f579831f36d52e3ec',
+    #                'smiles',
+    #                [], 'regression', 'qm7b', ['qm7b.mat'], 'random', 'MAE'),
     'QM8': Config('https://s3-us-west-1.amazonaws.com/deepchem.io/datasets/molnet_publish/qm8.zip',
                   '3445cc0fb829dc36e34e7935e2643cf2',
                   'gdb9_index',  # This is index for SDF file, not smiles
